@@ -11,6 +11,8 @@ import difflib
 import re
 import os
 
+docker = False
+
 def commit(init, comment = ''):
 	# get new files
 	new_files, new_lm, old_files, old_lm = init.getListtoCompare()
@@ -201,7 +203,7 @@ def updateHistory(init,commits):
 def updateFileHistory(init,key,commit):
 	# loads file global
 	metapath = init.prefix_history+key+'/history.json'
-	if init.storage.checkIfEmpty(init.prefix_history): 
+	if init.storage.checkIfEmpty(init.prefix_history+key+'/'): 
 		history = {}
 		history[1] = commit
 	else:
